@@ -11,7 +11,7 @@ from .utils import handle_youtube
 QUALITY = "360p"
 
 
-def read_vids(vids, worker_id, take_every_nth, resize_size, queue_export):
+def read_vids(vids, worker_id, take_every_nth, resize_size, batch_size, queue_export):
     """
     Reads list of videos, saves frames to SharedQueue
 
@@ -20,6 +20,7 @@ def read_vids(vids, worker_id, take_every_nth, resize_size, queue_export):
       worker_id - unique ID of worker
       take_every_nth - offset between frames of video (to lower FPS)
       resize_size - new pixel height and width of resized frame
+      batch_size - max length of frame sequence to put on shared_queue (-1 = no max).
       queue_export - SharedQueue export used re-create SharedQueue object in worker
     """
     queue = SharedQueue.from_export(*queue_export)
@@ -49,9 +50,19 @@ def read_vids(vids, worker_id, take_every_nth, resize_size, queue_export):
             print(f"Error: couldn't read video {vid}")
             return
 
-        frame_count = int(len(out) / (resize_size * resize_size * 3))  # can do this since dtype = np.uint8 (byte)
-        vid_frames = np.frombuffer(out, np.uint8).reshape((frame_count, resize_size, resize_size, 3))
-        queue.put(vid_frames, dst_name)
+        f_ct = int(len(out) / (resize_size * resize_size * 3))  # can do this since dtype = np.uint8 (byte)
+        np_frames = np.frombuffer(out, np.uint8).reshape((f_ct, resize_size, resize_size, 3))
+        pad_by = 0
+        if batch_size != -1:
+            pad_by = (batch_size - f_ct % batch_size) % batch_size
+            np_frames = np.pad(np_frames, ((0, pad_by), (0, 0), (0, 0), (0, 0)))
+            np_frames = np_frames.reshape((-1, batch_size, resize_size, resize_size, 3))
+
+        info = {
+            "dst_name": dst_name,
+            "pad_by": pad_by,
+        }
+        queue.put(np_frames, info)
 
     random.Random(worker_id).shuffle(vids)
     for vid in vids:
