@@ -36,9 +36,11 @@ def video2numpy(src, dest="", take_every_nth=1, resize_size=224, workers=1, memo
     else:
         fnames = src
 
-    reader = FrameReader(fnames, take_every_nth, resize_size, workers, memory_size)
+    batch_size = -1
+    reader = FrameReader(fnames, take_every_nth, resize_size, batch_size, workers, memory_size)
     reader.start_reading()
 
-    for vid_frames, dst_name in reader:
+    for vid_frames, info in reader:
+        dst_name = info["dst_name"]
         save_pth = os.path.join(dest, dst_name)
         np.save(save_pth, vid_frames)
